@@ -17,7 +17,7 @@ use rayon::prelude::*;
 use crate::{
     graph_ops::{DeserializeGraphOp, SerializeGraphOp},
     index::{AtomicIdx, Idx},
-    input::{edgelist::EdgeList, Direction, DotGraph, MyCypherValue},
+    input::{edgelist::EdgeList, Direction, DotGraph},
     DirectedDegrees, DirectedNeighbors, DirectedNeighborsWithValues, Error, Graph,
     NodeValues as NodeValuesTrait, SharedMut, UndirectedDegrees, UndirectedNeighbors,
     UndirectedNeighborsWithValues,
@@ -530,13 +530,23 @@ where
     }
 }
 
-impl<'a, NI, EV> From<(&'a gdl::Graph, CsrLayout)> for DirectedCsrGraph<NI, (), EV>
+impl<NI, Label> From<(DotGraph<NI, Label>, CsrLayout)> for DirectedCsrGraph<NI, Label>
 where
     NI: Idx,
-    EV: From<MyCypherValue<'a>> + Default + Copy + Send + Sync,
+    Label: Idx + Hash,
 {
-    fn from((gdl_graph, csr_layout): (&'a gdl::Graph, CsrLayout)) -> Self {
-        DirectedCsrGraph::from((EdgeList::from(gdl_graph), csr_layout))
+    fn from((dot_graph, csr_layout): (DotGraph<NI, Label>, CsrLayout)) -> Self {
+        let DotGraph {
+            label_frequencies: _,
+            edge_list,
+            labels,
+            max_degree: _,
+            max_label: _,
+        } = dot_graph;
+
+        let node_values = NodeValues::new(labels);
+
+        DirectedCsrGraph::from((node_values, edge_list, csr_layout))
     }
 }
 
@@ -562,16 +572,6 @@ where
     }
 }
 
-impl<NI, EV> From<(gdl::Graph, CsrLayout)> for DirectedCsrGraph<NI, (), EV>
-where
-    NI: Idx,
-    for<'a> EV: From<MyCypherValue<'a>> + Default + Copy + Send + Sync,
-{
-    fn from((gdl_graph, csr_layout): (gdl::Graph, CsrLayout)) -> Self {
-        DirectedCsrGraph::from((EdgeList::from(&gdl_graph), csr_layout))
-    }
-}
-
 impl<R, NI, NV, EV> DeserializeGraphOp<R, Self> for DirectedCsrGraph<NI, NV, EV>
 where
     R: Read,
@@ -734,23 +734,23 @@ where
     }
 }
 
-impl<'a, NI, EV> From<(&'a gdl::Graph, CsrLayout)> for UndirectedCsrGraph<NI, (), EV>
+impl<NI, Label> From<(DotGraph<NI, Label>, CsrLayout)> for UndirectedCsrGraph<NI, Label>
 where
     NI: Idx,
-    EV: From<MyCypherValue<'a>> + Default + Copy + Send + Sync,
+    Label: Idx + Hash,
 {
-    fn from((gdl_graph, csr_layout): (&'a gdl::Graph, CsrLayout)) -> Self {
-        UndirectedCsrGraph::from((EdgeList::from(gdl_graph), csr_layout))
-    }
-}
+    fn from((dot_graph, csr_layout): (DotGraph<NI, Label>, CsrLayout)) -> Self {
+        let DotGraph {
+            label_frequencies: _,
+            edge_list,
+            labels,
+            max_degree: _,
+            max_label: _,
+        } = dot_graph;
 
-impl<NI, EV> From<(gdl::Graph, CsrLayout)> for UndirectedCsrGraph<NI, (), EV>
-where
-    NI: Idx,
-    for<'a> EV: From<MyCypherValue<'a>> + Default + Copy + Send + Sync,
-{
-    fn from((gdl_graph, csr_layout): (gdl::Graph, CsrLayout)) -> Self {
-        UndirectedCsrGraph::from((EdgeList::from(&gdl_graph), csr_layout))
+        let node_values = NodeValues::new(labels);
+
+        UndirectedCsrGraph::from((node_values, edge_list, csr_layout))
     }
 }
 
