@@ -5,9 +5,6 @@ pub use crate::graph::csr::DirectedCsrGraph;
 pub use crate::graph::csr::Target;
 pub use crate::graph::csr::UndirectedCsrGraph;
 
-pub use crate::graph::labeled::DirectedNodeLabeledCsrGraph;
-pub use crate::graph::labeled::UndirectedNodeLabeledCsrGraph;
-
 pub use crate::graph_ops::DegreePartitionOp;
 pub use crate::graph_ops::ForEachNodeParallelByPartitionOp;
 pub use crate::graph_ops::ForEachNodeParallelOp;
@@ -24,7 +21,6 @@ pub use crate::DirectedDegrees;
 pub use crate::DirectedNeighbors;
 pub use crate::DirectedNeighborsWithValues;
 pub use crate::Graph;
-pub use crate::NodeLabeledGraph;
 pub use crate::NodeValues;
 pub use crate::UndirectedDegrees;
 pub use crate::UndirectedNeighbors;
